@@ -158,8 +158,10 @@ async def load(request: Request, params: dict):
             new_headers = CIMultiDict(
                 **headers, **{"content-type": "multipart/form-data"}  # type: ignore
             )
-            new_request = request.clone(headers=new_headers)
-            args_to_apply[name] = new_request
+            request.headers = new_headers
+            file = (await request.post()).get('file')
+            assert isinstance(file, FileField), "File not found"
+            args_to_apply[name] = file
         elif issubclass(annotation, BaseModel):
             data = await request.json(loads=JSONDecoder().decode)
             if isinstance(data, (str, bytes)):
@@ -170,7 +172,7 @@ async def load(request: Request, params: dict):
     return args_to_apply
 
 
-html = """<!DOCTYPE html>
+HTML_STRING = """<!DOCTYPE html>
             <html lang="en">
             <head>
                 <meta charset="UTF-8">
