@@ -76,7 +76,7 @@ class FaunaModel(JSONModel, metaclass=FaunaModelMetaclass):
 
                 cls.logger.info("Created index %s", cls.__name__.lower())
 
-            for field in cls.model_fields.values():
+            for field in cls.__fields__.values():
                 if field.field_info.extra.get("unique"):
                     if not await _q(
                         q.exists(q.index(f"{cls.__name__.lower()}_{field.name}_unique"))
