@@ -13,10 +13,11 @@ from aiohttp.web_ws import WebSocketResponse
 from aiohttp_sse import EventSourceResponse, sse_response
 
 from .client import APIClient
-from .docs import extract, html, load, transform
+from .docs import HTML_STRING, extract, load, transform
 from .helpers import do_response
 from .json import jsonable_encoder
 from .odm import FaunaModel
+from .router import APIRouter
 from .utils import setup_logging
 
 Middleware = Callable[[Request, Handler], Awaitable[StreamResponse]]
@@ -31,6 +32,7 @@ class APIServer(Application):
             "openapi": "3.0.0",
             "info": {"title": "AioFauna", "version": "1.0.0"},
             "paths": {},
+            "tags": [],
             "components": {"schemas": {}},
             "description": "AioFauna API",
         }
@@ -43,7 +45,7 @@ class APIServer(Application):
 
         @self.get("/docs")
         async def docs():
-            return Response(text=html, content_type="text/html")
+            return Response(text=HTML_STRING, content_type="text/html")
 
         @self.on_event("startup")
         async def startup(_):
@@ -259,3 +261,18 @@ class APIServer(Application):
 
         self.middlewares.append(wrapper)
         return wrapper
+
+    def include_router(self, router: APIRouter, prefix:str="") -> "APIServer":
+        """Chainable method to add a router to the server"""
+        for route in router.routes:
+            path = prefix + route.path
+            self.router.add_route(route.method, prefix+router.prefix+path, route.handler, **route.kwargs)
+
+        for path, details in router.openapi["paths"].items():
+            path = prefix + path
+            self.openapi["paths"][path] = details
+    
+        self.openapi["components"]["schemas"].update(
+            router.openapi["components"]["schemas"]
+        )
+        return self
\ No newline at end of file
