@@ -2,7 +2,7 @@
 import functools
 import logging
 from time import perf_counter
-from typing import Any, Callable, Coroutine, TypeVar, cast
+from typing import Any, Callable, Coroutine, Generator, Sequence, TypeVar, cast
 
 from aiohttp.web_exceptions import HTTPException
 from rich.console import Console
@@ -94,8 +94,16 @@ def handle_errors(
     return wrapper
 
 
-def chunker(seq, size):
-    return (seq[pos : pos + size] for pos in range(0, len(seq), size))
+def chunker(seq:Sequence[T], size:int) -> Generator[Sequence[T], None, None]:
+    """
+    A generator function that chunks a sequence into smaller sequences of the given size.
+
+    Arguments:
+    seq -- The sequence to be chunked.
+    size -- The size of the chunks.
+    """
+    return (seq[pos:pos + size] for pos in range(0, len(seq), size))
+
 
 
 def gen_emptystr() -> str:
